#pragma once

#include <string>

// Trivial implementation of a natural sort algorithm
class NaturalSort
{
    static bool IsNumeric(const std::wstring & str, const size_t index)
    {
        const auto c = str[index];
        if (isdigit(c)) return true;
        if (c != L'.' && c != L',') return false;
        if (str.size() > index + 1 && isdigit(str[index + 1])) return true;
        return false;
    }

public:

    static int Compare(const std::wstring & a, const std::wstring & b)
    {
        const auto lenA = a.size(), lenB = b.size();
        size_t iA = 0, iB = 0, firstDifference = wstring::npos;
        while (iA < lenA && iB < lenB)
        {
            const auto charA = a[iA], charB = b[iB];
            if (isdigit(charA))
            {
                if (!isdigit(charB)) { return -1; }
                size_t digitsA = 1, digitsB = 1;
                while (iA + digitsA < lenA && IsNumeric(a, iA + digitsA)) { ++digitsA; }
                while (iB + digitsB < lenB && IsNumeric(b, iB + digitsB)) { ++digitsB; }
                const auto numberA = a.substr(iA, digitsA), numberB = b.substr(iB, digitsB);
                if (digitsA != digitsB || numberA != numberB) // no point comparing numbers if the strings match
                {
                    const double doubleA = std::stod(numberA), doubleB = std::stod(numberB);
                    if (doubleA < doubleB) { return -1; }
                    if (doubleA > doubleB) { return 1; }
                    if (firstDifference == wstring::npos) { firstDifference = iA; } // at this point iA == iB
                }
                iA += digitsA;
                iB += digitsB;
                continue;
            }
            if (isdigit(charB)) { return 1; }
            if (charA < charB) { return -1; }
            if (charA > charB) { return 1; }
            ++iA;
            ++iB;
        }
        if (iA == lenA && iB == lenB)
        {
            if (firstDifference == wstring::npos) { return 0; } // the strings had no differences
            // the strings are naturally equivalent, but started to differ after 'firstDifference' 
            while (firstDifference < lenA && firstDifference < lenB)
            {
                const auto charA = a[firstDifference], charB = b[firstDifference];
                if (charA < charB) { return -1; }
                if (charA > charB) { return 1; }
                ++firstDifference;
            }
            return firstDifference < lenA ? 1 : -1;
        }
        return iA < lenA ? 1 : -1;
    }

    static bool Ascending(const std::wstring & a, const std::wstring & b)
    {
        return Compare(a, b) < 0;
    }

    static bool Descending(const std::wstring & a, const std::wstring & b)
    {
        return Compare(a, b) > 0;
    }
};
