#include "Tutorials.h"

using namespace SolidFramework::Platform;

//#define __SOLIDWINXP__

int RunSamples()
{
    // Allow SolidFramework to treat '\' and '/' as the platform-specific directory separator
    SolidFramework::SupportPlatformIndependentPaths(true);

    // The license is assumed to be in the SolidFramework folder, and to be called license.xml;
    const wstring licensePathRaw = L"license.xml";

    // The file to be converted
    const wstring inputFileRaw = L"brewpub.pdf";

    // Set the license and SDK paths
#if defined (__SOLIDMAC__)
    const wstring licensePath = L"..\\..\\..\\SolidFramework\\" + licensePathRaw;
    const wstring frameworkPath = L"..\\..\\..\\SolidFramework\\" + SolidFramework::GetTargetPlatformName() + L"\\Frameworks\\SolidFrameworkNative.framework\\Libraries";
#elif defined (__SOLIDLINUX__)
    const wstring licensePath = L"..\\SolidFramework\\" + licensePathRaw;
    const wstring frameworkPath = L"..\\SolidFramework\\" + SolidFramework::GetTargetPlatformName();
#elif defined (__SOLIDWINXP__)
    WCHAR buff[MAX_PATH + 1] = { 0 };
    ::GetModuleFileName(nullptr, buff, MAX_PATH);
    const wstring fullPath = wstring(buff).substr(0, wstring(buff).rfind(L'\\') + 1);
    const wstring licensePath = fullPath + L"..\\SolidFramework\\" + licensePathRaw;
    const wstring frameworkPath = fullPath + L"..\\SolidFramework\\" + SolidFramework::GetTargetPlatformName();
    ::SetCurrentDirectory(frameworkPath.c_str());
#else
    const wstring licensePath = L"..\\SolidFramework\\" + licensePathRaw;;
    const wstring frameworkPath = L"..\\SolidFramework\\" + SolidFramework::GetTargetPlatformName();
#endif
    
    // Initialize SolidFramework and import the license
    if (!InitializeSolidFramework(frameworkPath, licensePath))
    {
        wcout << L"SolidFramework initialization failed." << endl;
        return -1;
    }

    // Set the path to the input file
#if defined (__SOLIDMAC__)
    const wstring inputFile = L"..\\..\\Examples\\" + inputFileRaw;
#elif defined (__SOLIDLINUX__)
    const wstring inputFile = L"..\\C++ Tutorials\\Examples\\" + inputFileRaw;
#elif defined (__SOLIDWINXP__)
    const wstring inputFile = fullPath + L"Examples\\" + inputFileRaw;
#else
    const wstring inputFile = L"Examples\\" + inputFileRaw;
#endif

    const wstring filename = Path::GetFileNameWithoutExtension(inputFile);

    // PDF conversion samples

    ConvertPdfToWord(inputFile, Path::ChangeExtension(inputFile, L".docx"));
    ConvertPdfToHtml(inputFile, Path::ChangeExtension(inputFile, L".html"));
    ConvertPdfToExcel(inputFile, Path::ChangeExtension(inputFile, L".xlsx"));
    ConvertPdfToData(inputFile, Path::ChangeExtension(inputFile, L".csv"));
    ConvertPdfToPowerPoint(inputFile, Path::ChangeExtension(inputFile, L".pptx"));
    ConvertPdfToImages(inputFile, Path::ChangeFileName(inputFile, filename + L"-rendered-pages")); // folder
    ExtractPdfImages(inputFile, Path::ChangeFileName(inputFile, filename + L"-extracted-images")); // folder
    ExtractPdfText(inputFile, Path::ChangeExtension(inputFile, L".txt"));

    // Scanning and archiving samples

    ConvertPdfToPdfA(inputFile, Path::ChangeFileName(inputFile, filename + L"-pdfa.pdf"));
    MakePdfSearchable(inputFile, Path::ChangeFileName(inputFile, filename + L"-searchable.pdf"));
    //OcrTransformer(inputFile, Path::ChangeFileName(inputFile, filename + L"-ocr-transform.pdf")); // Not available in C++
    //ConvertTiffToPdf(tiffFile, Path::ChangeExtension(tiffFile, ".pdf")) // Not available in C++
    ValidatePdfA(inputFile, Path::ChangeFileName(inputFile, L"PDF-A Report.xml"));

    // PDF manipulation samples

    const wstring extractedPagesFolder = Path::ChangeFileName(inputFile, filename + L"-pages");
    ExtractPdfPages(inputFile, extractedPagesFolder); // folder
    CombinePdfFiles(extractedPagesFolder, Path::ChangeFileName(inputFile, filename + L"-recombined.pdf"));
    EditDocumentProperties(inputFile, Path::ChangeFileName(inputFile, filename + L"-modified-properties.pdf"));
    SecurePdfFile(inputFile, Path::ChangeFileName(inputFile, filename + L"-secure.pdf"));
    SetViewerPreferences(inputFile, Path::ChangeFileName(inputFile, filename + L"-viewer-preferences.pdf"));

    return 0;
}


int main()
{
    try
    {
        return RunSamples();
    }
    catch (exception &ex)
    {
        wcout << L"Unhandled std::exception: " << ex.what() << endl;
        return -2;
    }
    catch (...)
    {
        wcout << L"Unhandled Exception!" << endl;
        return -3;
    }
}

