#include "Tutorials.h"
#include <algorithm>
#include "NaturalSort.h"
// NaturalSort.h is used for the optional sort, it can be found in the full sample

using namespace SolidFramework::Platform;
using namespace SolidFramework::Pdf;


bool CombinePdfFiles(const wstring & inputFolder, const wstring & outputPath)
{
    // Get the list of files to combine
    vector<wstring> filesToCombine;
    for (const wstring & file : Directory::GetFiles(inputFolder, false))
    {
        if (Path::GetExtension(file) == L".pdf")
        {
            filesToCombine.push_back(file);
        }
    }
    if (filesToCombine.empty())
    {
        wcout << L"Could not find any pdf files to combine in " << inputFolder << endl;
        return false;
    }

    // Optional: Sort the list of files
    sort(filesToCombine.begin(), filesToCombine.end(), NaturalSort::Ascending);

    wcout << L"Combining PDFs from " << inputFolder << L" into " << outputPath << endl;

    // Create a PdfDocument and open the first PDF file
    auto document = make_shared<PdfDocument>(filesToCombine[0]);
    document->Open();

    // Add the rest of the files
    for (auto iterator = ++filesToCombine.begin(); iterator != filesToCombine.end(); ++iterator)
    {
        // Create another PdfDocument and open the next file
        auto nextDocument = make_shared<PdfDocument>(*iterator);
        nextDocument->Open();

        // Append this PdfDocument to the first PdfDocument
        document->Append(nextDocument);
    }
    // Save the combined PdfDocument
    document->SaveAs(outputPath, SolidFramework::Plumbing::OverwriteMode::ForceOverwrite);

    wcout << L"Successfully combined PDFs from " << inputFolder << L" into " << outputPath << endl << endl;
    return true;
}