#include "Tutorials.h"

using namespace SolidFramework::Converters::Plumbing;
using namespace SolidFramework::Converters;

bool ConvertPdfToData(const wstring & pdfPath, const wstring & outputPath)
{
    // Create a PdfToDataConverter
    auto converter = make_shared<PdfToDataConverter>();

    // Add the PDF file to convert
    converter->AddSourceFile(pdfPath);

    // Set the data format to output as
    converter->SetExportFormat(DataExportFormat::Text);
    converter->SetDelimiterOption(DelimiterOptions::Comma); // CSV

    // Optional: Set PdfToDataConverter options to your liking
    converter->SetSingleTable(ExcelTablesOnSheet::PlaceEachTableOnOwnSheet);
    converter->SetDetectTiledPages(true);

    // Optional: Add a progress/warning handler
    double nextPercentToLog = 25;
    converter->OnProgress = [&nextPercentToLog] (SolidFramework::ProgressEventArgsPtr progress)
    {
        const double percent = progress->GetProgress() * 100.0  / progress->GetMaxProgress();
        if (percent < nextPercentToLog || (percent > 70 && nextPercentToLog < 30)) { return; }
        wcout << progress->GetStatusDescription() << L" " << percent  << L"%" << endl;
        nextPercentToLog = percent > 70 ? 25 : nextPercentToLog + 25;
    };

    wcout << L"Converting " << pdfPath << L" to " << outputPath << endl;

    // Convert the file
    auto result = converter->ConvertTo(outputPath, true);

    // Check if it was successful
    if (result != ConversionStatus::Success)
    {
        wcout << L"Converting " << pdfPath << L" to " << outputPath << L" failed with status: " << (int)result << endl << endl;
        return false;
    }
    wcout << L"Successfully converted " << pdfPath << L" to " << outputPath << endl << endl;
    return true;
}