#include "Tutorials.h"

using namespace SolidFramework::Converters::Plumbing;
using namespace SolidFramework::Converters;

bool ConvertPdfToImages(const wstring & pdfPath, const wstring & outputFolder)
{
    // Create a PdfToImageConverter
    auto converter = make_shared<PdfToImageConverter>();

    // Add the PDF file to convert
    converter->AddSourceFile(pdfPath);

    // Set the output folder and overwrite mode
    converter->SetOutputDirectory(outputFolder);
    converter->SetOverwriteMode(SolidFramework::Plumbing::OverwriteMode::ForceOverwrite);

    // Set the conversion type to ExtractPages
    converter->SetConversionType(ImageConversionType::ExtractPages);

    // Optional: Set PdfToImageConverter options to your liking
    converter->SetPageDPI(300);
    converter->SetOutputType(ImageDocumentType::Png);

    wcout << L"Converting " << pdfPath << L" to images in folder " << outputFolder << endl;

    // Convert the file
    converter->Convert();

    // Check the results were successful
    for (const auto & result : converter->GetResults())
    {
        if (result->GetStatus() != ConversionStatus::Success)
        {
            wcout << L"Converting " << pdfPath << L" to images failed with status: " << (int)result->GetStatus() << endl << endl;
            return false;
        }
    }
    wcout << L"Successfully converted " << pdfPath << L" to images" << endl << endl;
    return true;
}