#include "Tutorials.h"

using namespace SolidFramework::Converters::Plumbing;
using namespace SolidFramework::Converters;

bool ConvertPdfToPdfA(const wstring & pdfPath, const wstring & outputPath)
{
    // Create a PdfToPdfAConverter
    auto converter = make_shared<PdfToPdfAConverter>();

    // Add the PDF file to convert
    converter->AddSourceFile(pdfPath);
    
    // Set the PDF/A mode to convert to
    converter->SetValidationMode(SolidFramework::Plumbing::ValidationMode::PdfA2B);

    // Optional: Set OCR options to your liking (requires an OCR license)
    if (SolidFramework::License::Allows(SolidFramework::Plumbing::LicensePermissions::Ocr))
    {
        converter->SetOcrEngine(TextRecoveryEngine::SolidOCR);
        converter->SetOcrType(OcrType::CreateSearchableTextLayer);
        converter->SetOcrLanguage(L"au"); // automatic language detection
    }

    wcout << L"Converting " << pdfPath << L" to " << outputPath << endl;

    // Convert the file
    auto result = converter->ConvertTo(outputPath, true);

    // Check if it was successful (PdfAError means it wasn't PDF/A but was fixed)
    if (result != ConversionStatus::Success && result != ConversionStatus::PdfAError)
    {
        wcout << L"Converting " << pdfPath << L" to " << outputPath << L" failed with status: " << (int)result << endl << endl;
        return false;
    }
    wcout << L"Successfully converted " << pdfPath << L" to " << outputPath << endl << endl;
    return true;
}