#include "Tutorials.h"

using namespace SolidFramework::Converters::Plumbing;
using namespace SolidFramework::Converters;

bool ExtractPdfImages(const wstring & pdfPath, const wstring & outputFolder)
{
    // Create a PdfToImageConverter
    auto converter = make_shared<PdfToImageConverter>();

    // Add the PDF file to extract images from
    converter->AddSourceFile(pdfPath);

    // Set the output folder and overwrite mode
    converter->SetOutputDirectory(outputFolder);
    converter->SetOverwriteMode(SolidFramework::Plumbing::OverwriteMode::ForceOverwrite);

    // Set the conversion type to ExtractImages
    converter->SetConversionType(ImageConversionType::ExtractImages);

    // Optional: Set PdfToImageConverter options to your liking
    converter->SetOutputType(ImageDocumentType::Default);

    wcout << L"Extracting images from " << pdfPath << L" into folder " << outputFolder << endl;

    // Call Convert to extract the images
    converter->Convert();

    // Check the results were successful
    for (const auto & result : converter->GetResults())
    {
        if (result->GetStatus() != ConversionStatus::Success)
        {
            wcout << L"Extracting images from " << pdfPath << L" failed with status: " << (int)result->GetStatus() << endl << endl;
            return false;
        }
    }
    wcout << L"Successfully extracted images from " << pdfPath << endl << endl;
    return true;
}