#include "Tutorials.h"

using namespace SolidFramework::Platform;
using namespace SolidFramework::Model::Pdf::Pages;

bool ExtractPdfPages(const wstring & pdfPath, const wstring & outputFolder)
{
    // Create a PagesModel
    auto model = make_shared<PagesModel>();

    // Open the PDF file
    model->OpenPDF(pdfPath);

    // Set the base path for the output files
    const wstring basePath = Path::Combine(outputFolder, Path::GetFileNameWithoutExtension(pdfPath));

    // Get the page count
    const int pageCount = model->GetPageCount();

    // Create a std::vector<int> to store selected page indexes in
    vector<int> selectedPages;

    wcout << L"Extracting pages from " << pdfPath << L" into " << outputFolder << endl;

    // Iterate over each page
    for (int pageIndex = 0; pageIndex < pageCount; pageIndex++)
    {
        // Set the models selection to the current page index
        selectedPages.push_back(pageIndex);
        model->SetSelection(selectedPages);
        selectedPages.clear();

        // Save the model's selection to the output folder
        model->Save(basePath + L"-" + to_wstring(pageIndex + 1) + L".pdf", true);
    }

    wcout << L"Successfully extracted pages from " << pdfPath << L" into " << outputFolder << endl << endl;
    return true;
}