#include "Tutorials.h"

using namespace SolidFramework::Converters::Plumbing;
using namespace SolidFramework::Converters;

bool MakePdfSearchable(const wstring & pdfPath, const wstring & outputPath)
{
    // Ensure license allows OCR
    if (!SolidFramework::License::Allows(SolidFramework::Plumbing::LicensePermissions::Ocr))
    {
        wcout << L"License doesn't allow OCR - skipping MakePdfSearchable" << endl << endl;
        return false;
    }

    // Create a PdfToPdfAConverter
    auto converter = make_shared<PdfToPdfAConverter>();

    // Add the PDF file to convert
    converter->AddSourceFile(pdfPath);
    
    // Set the PDF/A mode to convert to
    converter->SetValidationMode(SolidFramework::Plumbing::ValidationMode::PdfA2B);

    // Add a searchable text layer (requires a Professional+OCR license)
    converter->SetOcrType(OcrType::CreateSearchableTextLayer);
    converter->SetOcrEngine(TextRecoveryEngine::SolidOCR);
    converter->SetOcrLanguage(L"en");
    converter->SetOcrImageCompression(SolidFramework::Imaging::Plumbing::ImageCompression::PreserveOriginal);

    wcout << L"Converting " << pdfPath << L" to " << outputPath << endl;

    // Convert the file
    auto result = converter->ConvertTo(outputPath, true);

    // Check if it was successful (PdfAError means it wasn't PDF/A but was fixed)
    if (result != ConversionStatus::Success && result != ConversionStatus::PdfAError)
    {
        wcout << L"Converting " << pdfPath << L" to " << outputPath << L" failed with status: " << (int)result << endl << endl;
        return false;
    }
    wcout << L"Successfully converted " << pdfPath << L" to " << outputPath << endl << endl;
    return true;
}