#include "Tutorials.h"

using namespace SolidFramework::Pdf;

bool SecurePdfFile(const wstring & pdfPath, const wstring & outputPath)
{
    // Create a PdfDocument and open the PDF file
    auto document = make_shared<PdfDocument>(pdfPath);
    document->Open();

    // Create a Security Handler
    auto securityHandler = make_shared<PdfPasswordSecurityHandler>();

    // Set an owner password and an open password
    securityHandler->SetOwnerPassword(L"owner");
    securityHandler->SetOpenPassword(L"open");

    // Set the encryption algorithm to use
    securityHandler->SetEncryptionAlgorithm(EncryptionAlgorithm::Aes256Bits);

    // Optional: Restrict permissions
    securityHandler->SetPermissions(AccessPermissions::ContentEditing | AccessPermissions::Extracting);

    wcout << L"Adding security to " << outputPath << endl;

    // Set the path to save to
    document->SetPath(outputPath);

    // Save the PdfDocument with the new security handler
    document->SaveProtected(securityHandler, SolidFramework::Plumbing::OverwriteMode::ForceOverwrite);

    wcout << L"Successfully added security to " << outputPath << endl << endl;
    return true;
}