#include "Tutorials.h"

using namespace SolidFramework::Pdf;

bool SetViewerPreferences(const wstring & pdfPath, const wstring & outputPath)
{
    // Create a PdfDocument and open the PDF file
    auto document = make_shared<PdfDocument>(pdfPath);
    document->Open();

    // Get the documents catalog object
    auto catalog = Catalog::DynamicCast(document->GetCatalog());

    // Get the catalogs ViewerPreferences object (creating it if it doesn't exist)
    auto viewerPreferences = catalog->GetViewerPreferences(true);

    // Modify the viewer preferences to your liking
    viewerPreferences->SetHideMenuBar(true);
    viewerPreferences->SetHideToolBar(true);
    viewerPreferences->SetHideWindowUI(true);
    viewerPreferences->SetFitWindow(true);

    wcout << L"Updating viewer preferences for " << outputPath << endl;

    // Save the updated document
    document->SaveAs(outputPath, SolidFramework::Plumbing::OverwriteMode::ForceOverwrite);
    wcout << L"Successfully updated viewer preferences for " << outputPath << endl << endl;
    return true;
}