#include "Tutorials.h"

using namespace SolidFramework::Converters::Plumbing;
using namespace SolidFramework::Converters;

bool ValidatePdfA(const wstring & pdfPath, const wstring & outputPath)
{
    // Create a PdfToPdfAConverter
    auto converter = make_shared<PdfToPdfAConverter>();

    // Add the PDF file to validate
    converter->AddSourceFile(pdfPath);
    
    // Set the PDF/A mode to validate as
    converter->SetValidationMode(SolidFramework::Plumbing::ValidationMode::PdfA2B);

    wcout << L"Validating " << pdfPath << endl;

    // Validate the file
    converter->Validate();

    // Check the results
    auto results = converter->GetResults();
    for (const auto & result: results)
    {
        auto status = result->GetStatus();
        if (status != ConversionStatus::Success && status != ConversionStatus::PdfAError)
        {
            wcout << L"Validating " << pdfPath << L" failed with status " << (int)status << endl << endl;
            return false;
        }
    }

    // Save the report
    auto report = converter->GetReport();
    if (report == nullptr)
    {
        wcout << L"Validating " << pdfPath << L" did not create a report" << endl << endl;
        return false;
    }
    report->Save(outputPath);
    wcout << L"Successfully validated " << pdfPath << L". Report has been saved to " << outputPath << endl << endl;
    return true;
}